@@ -54,7 +54,7 @@
 #'
 #' # Multiple images, with interactive classification and a reference image
 #' snakes <- getimg(system.file("testdata/images/snakes", package = "pavo"))
-#' \dontrun{
+#' if (interactive()) {
 #' snakes_class <- classify(snakes, refID = "snake_01", interactive = TRUE)
 #' }
 #'
@@ -256,7 +256,7 @@ classifier <- function(imgdat_i2, n_cols_i2, method_i2) {
     outdata <- future_lapply(seq_along(imgdat_i2), function(x) {
       p()
       classify_main(imgdat_i2[[x]], n_cols_i2[[x]], method_i2)
-    })
+    }, future.seed = TRUE)
   })
 
   outdata
