@@ -49,9 +49,10 @@
 #'
 #' @keywords internal
 #'
-#' @importFrom grDevices trans3d dev.off pdf
-#' @importFrom graphics grconvertX grconvertY
+#' @importFrom graphics grconvertX grconvertY lines par points
 #' @importFrom plot3D perspbox
+#' @importFrom stats setNames
+#' @importFrom utils combn
 #'
 #' @references Stoddard, M. C., & Prum, R. O. (2008). Evolution of avian plumage
 #'   color in a tetrahedral color space: A phylogenetic analysis of new world
@@ -408,8 +409,11 @@ tetraplot <- function(tcsdata, theta = 45, phi = 10, perspective = FALSE,
     colnames(maxgamut) <- c("x", "y", "z")
     attr(maxgamut, "clrsp") <- "tcs"
     tryCatch(vol(maxgamut, grid = FALSE),
-             error = function(e) warning("Max gamut cannot be plotted.",
-                                         call. = FALSE))
-
+      error = function(e) {
+        warning("Max gamut cannot be plotted.",
+          call. = FALSE
+        )
+      }
+    )
   }
 }
